﻿using Syncfusion.Pdf;
using Syncfusion.Pdf.Graphics;
using Syncfusion.UI.Xaml.Charts;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Interop;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace ChartToPDF
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        SfChart chart1;
        PdfDocument pdfDoc;
        ViewModel model;
        public MainWindow()
        {
            InitializeComponent();
            model = new ViewModel();
            chart1 = new SfChart() { Background = Brushes.White};
            chart1.PrimaryAxis = new NumericalAxis();
            chart1.SecondaryAxis = new NumericalAxis()
            {
                EdgeLabelsDrawingMode = EdgeLabelsDrawingMode.Shift
            };
            ColumnSeries series = new ColumnSeries();
            series.ItemsSource = model.Collection;
            series.XBindingPath = "XValue";
            series.YBindingPath = "YValue";
            chart1.Series.Add(series);

            //To Render the Chart UI without showing the window 
            chart1.Measure(new Size(double.PositiveInfinity, double.PositiveInfinity));
            chart1.Arrange(new Rect(new Point(0, 0), chart1.DesiredSize));

            // Export to PDF
            pdfDoc = new PdfDocument();
            MemoryStream outStream = new MemoryStream();
            chart1.Save(outStream, new BmpBitmapEncoder());
            PdfPage page = pdfDoc.Pages.Add();
            PdfBitmap img = new PdfBitmap(outStream);
            page.Graphics.DrawImage(img, 0, 100, 400, 350);
            outStream.Close();
            string pdfFile = "chartpdf.pdf";
            pdfDoc.Save(pdfFile);
            System.Diagnostics.Process.Start(pdfFile);

            //Save chart 
            chart1.Save("chart.png");
        }

        static IntPtr ApplicationMessageFilter(IntPtr hwnd, int message, IntPtr wParam, IntPtr lParam, ref bool handled)
        {
            return IntPtr.Zero;
        }

        private void FrameworkElement_OnLoaded(object sender, RoutedEventArgs e)
        {
            string path = Environment.CurrentDirectory + "\\chart.png";
            BitmapImage b = new BitmapImage();
            b.BeginInit();
            b.UriSource = new Uri(path);
            b.EndInit();
            var image = sender as Image;
            image.Source = b;
        }
    }

    public class Model
    {
        public double XValue { get; set; }

        public double YValue { get; set; }
    }

    public class ViewModel
    {
        public ObservableCollection<Model> Collection { get; set; }
        public ViewModel()
        {
            Collection = new ObservableCollection<Model>();
            Collection.Add(new Model() { XValue = 1, YValue = 18 });
            Collection.Add(new Model() { XValue = 2, YValue = 32 });
            Collection.Add(new Model() { XValue = 3, YValue = 24 });
            Collection.Add(new Model() { XValue = 4, YValue = 42 });
            Collection.Add(new Model() { XValue = 5, YValue = 30 });
        }
    }
}
